@@ -1,5 +1,3 @@
-import logging
-
 from tornado.curl_httpclient import CurlAsyncHTTPClient
 
 from async_keepalive_httpc.aws.auth import EasyV4Sign
@@ -14,8 +12,6 @@ class AWSClient(object):
         self.region = region
         self.proxy_config = proxy_config
 
-        logger = logging.getLogger('awsclient')
-
         if not signer :
             assert None not in (access_key, secret_key, region)
             self.v4sign = EasyV4Sign(
@@ -28,9 +24,6 @@ class AWSClient(object):
             signer.service = self._service
 
         if self.proxy_config or use_curl:
-            #print 'using proxy_config %s' % self.proxy_config
-            if self.proxy_config:
-                logger.debug('using proxy_config %s' % self.proxy_config)
             self.client = CurlAsyncHTTPClient(self.io_loop)
             self.use_curl = True
         else:
